@@ -1,21 +1,7 @@
 /*
-    Copyright 2008 Sascha Peilicke <sasch.pe@gmx.de>
+    SPDX-FileCopyrightText: 2008 Sascha Peilicke <sasch.pe@gmx.de>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy
-    defined in Section 14 of version 3 of the license.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "game.h"
@@ -134,7 +120,7 @@ bool Game::init()
         m_movesList.clear();
         m_undoStack.clear();
 
-        emit boardChanged();
+        Q_EMIT boardChanged();
         return true;
     } else {
         return false;
@@ -176,8 +162,8 @@ bool Game::init(const QString &fileName, int moveNumber)
         m_movesList.clear();
         m_undoStack.clear();
 
-        emit boardSizeChanged(m_boardSize);
-        emit boardChanged();                             // All done, tell the world!
+        Q_EMIT boardSizeChanged(m_boardSize);
+        Q_EMIT boardChanged();                             // All done, tell the world!
         return true;
     } else {
         return false;
@@ -211,8 +197,8 @@ bool Game::setBoardSize(int size)
         m_currentMove = 0;
         m_movesList.clear();
         m_undoStack.clear();
-        emit boardSizeChanged(size);
-        emit boardChanged();
+        Q_EMIT boardSizeChanged(size);
+        Q_EMIT boardChanged();
         return true;
     } else {
         return false;
@@ -249,7 +235,7 @@ bool Game::setFixedHandicap(int handicap)
             // which means, white is next.
             setCurrentPlayer(m_whitePlayer);
             m_fixedHandicap = handicap;
-            emit boardChanged();
+            Q_EMIT boardChanged();
             return true;
         } else {
             return false;
@@ -316,9 +302,9 @@ bool Game::playMove(const Player &player, const Stone &stone, bool undoable)
             m_consecutivePassMoveNumber = 0;
         } else {                                // And pass move handling
             m_movesList.append(Move(tmp, Stone::Pass));
-            emit passMovePlayed(*m_currentPlayer);
+            Q_EMIT passMovePlayed(*m_currentPlayer);
             if (m_consecutivePassMoveNumber > 0) {
-                emit consecutivePassMovesPlayed(m_consecutivePassMoveNumber);
+                Q_EMIT consecutivePassMovesPlayed(m_consecutivePassMoveNumber);
             }
             m_consecutivePassMoveNumber++;
         }
@@ -357,7 +343,7 @@ bool Game::playMove(const Player &player, const Stone &stone, bool undoable)
             setCurrentPlayer(m_whitePlayer);
         }
 
-        emit boardChanged();
+        Q_EMIT boardChanged();
         return true;
     } else {
         return false;
@@ -397,9 +383,9 @@ bool Game::generateMove(const Player &player, bool undoable)
         }
         if (m_response == QLatin1String("PASS")) {
             m_currentMove++;
-            emit passMovePlayed(*m_currentPlayer);
+            Q_EMIT passMovePlayed(*m_currentPlayer);
             if (m_consecutivePassMoveNumber > 0) {
-                emit consecutivePassMovesPlayed(m_consecutivePassMoveNumber);
+                Q_EMIT consecutivePassMovesPlayed(m_consecutivePassMoveNumber);
                 m_gameFinished = true;
             }
             m_consecutivePassMoveNumber++;
@@ -410,7 +396,7 @@ bool Game::generateMove(const Player &player, bool undoable)
                 undoStr = i18n("Black passed");
             }
         } else if (m_response == QLatin1String("resign")) {
-            emit resigned(*m_currentPlayer);
+            Q_EMIT resigned(*m_currentPlayer);
             m_gameFinished = true;
             moveType = UndoCommand::MoveType::Resigned;
             if (tmp->isWhite()) {
@@ -441,7 +427,7 @@ bool Game::generateMove(const Player &player, bool undoable)
             setCurrentPlayer(m_whitePlayer);
         }
         if (boardChange) {
-            emit boardChanged();
+            Q_EMIT boardChanged();
         }
         return true;
     } else {
@@ -479,7 +465,7 @@ bool Game::undoMove()
         //TODO: What happens with pass moves deeper in the history?
         m_undoStack.undo();
 
-        emit boardChanged();
+        Q_EMIT boardChanged();
         return true;
     } else {
         return false;
@@ -503,9 +489,9 @@ bool Game::redoMove()
         // Note: Although it is possible to undo after a resign and redo it,
         //       it is a bit questionable whether this makes sense logically.
         //qCDebug(KIGO_LOG) << "Redo a resign for" << player << undoCmd->text();
-        emit resigned(*player);
+        Q_EMIT resigned(*player);
         m_gameFinished = true;
-        //emit resigned(*m_currentPlayer);
+        //Q_EMIT resigned(*m_currentPlayer);
     } else {
         //qCDebug(KIGO_LOG) << "Redo a normal move for" << player << undoCmd->text();
         playMove(*player, Stone(undoCmd->text()), false);
@@ -544,7 +530,8 @@ QList<Stone> Game::stones(const Player &player)
     if (!player.isWhite()) {
         m_process.write("list_stones black\n");
         if (waitResponse() && !m_response.isEmpty()) {
-            foreach (const QString &pos, m_response.split(QLatin1Char(' '))) {
+            const auto positions = m_response.split(QLatin1Char(' '));
+            for (const QString &pos : positions) {
                 list.append(Stone(pos));
             }
         }
@@ -552,7 +539,8 @@ QList<Stone> Game::stones(const Player &player)
     if (!player.isBlack()) {
         m_process.write("list_stones white\n");
         if (waitResponse() && !m_response.isEmpty()) {
-            foreach (const QString &pos, m_response.split(QLatin1Char(' '))) {
+            const auto positions = m_response.split(QLatin1Char(' '));
+            for (const QString &pos : positions) {
                 list.append(Stone(pos));
             }
         }
@@ -570,7 +558,7 @@ QList<Move> Game::moves(const Player &player)
     if (!player.isValid()) {
         list = m_movesList;
     } else {
-        foreach (const Move &move, m_movesList) {
+        for (const Move &move : qAsConst(m_movesList)) {
             if (move.player()->color() == player.color()) {
                 list.append(move);
             }
@@ -588,7 +576,8 @@ QList<Stone> Game::liberties(const Stone &stone)
 
     m_process.write("findlib " + stone.toLatin1() + '\n');
     if (waitResponse() && !m_response.isEmpty()) {
-        foreach (const QString &entry, m_response.split(QLatin1Char(' '))) {
+        const auto entries = m_response.split(QLatin1Char(' '));
+        for (const QString &entry : entries) {
             list.append(Stone(entry));
         }
     }
@@ -631,7 +620,8 @@ QList<Stone> Game::legalMoves(const Player &player)
         m_process.write("all_legal black\n");
     }
     if (waitResponse() && !m_response.isEmpty()) {
-        foreach (const QString &entry, m_response.split(QLatin1Char(' '))) {
+        const auto entries = m_response.split(QLatin1Char(' '));
+        for (const QString &entry : entries) {
             list.append(Stone(entry));
         }
     }
@@ -692,7 +682,8 @@ QList<Stone> Game::finalStates(FinalState state)
     msg.append('\n');
     m_process.write(msg);
     if (waitResponse() && !m_response.isEmpty()) {
-        foreach (const QString &entry, m_response.split(QLatin1Char(' '))) {
+        const auto entries = m_response.split(QLatin1Char(' '));
+        for (const QString &entry : entries) {
             list.append(Stone(entry));
         }
     }
@@ -735,7 +726,7 @@ bool Game::waitResponse(bool nonBlocking)
     }
 
     if (nonBlocking) {
-        emit waiting(true);
+        Q_EMIT waiting(true);
     }
 
     // Wait for finished command execution. We have to do this untill '\n\n' (or '\r\n\r\n' or
@@ -760,7 +751,7 @@ bool Game::waitResponse(bool nonBlocking)
              !m_response.endsWith(QLatin1String("\r\n\r\n")));
 
     if (nonBlocking) {
-        emit waiting(false);
+        Q_EMIT waiting(false);
     }
 
     if (m_response.size() < 1) {
@@ -774,7 +765,7 @@ bool Game::waitResponse(bool nonBlocking)
 
 void Game::gameSetup()
 {
-    emit boardInitialized();
+    Q_EMIT boardInitialized();
 }
 
 void Game::readyRead()
@@ -790,7 +781,7 @@ void Game::undoIndexChanged(int index)
 void Game::setCurrentPlayer(Player &player)
 {
     m_currentPlayer = &player;
-    emit currentPlayerChanged(*m_currentPlayer);
+    Q_EMIT currentPlayerChanged(*m_currentPlayer);
 }
 
 } // End of namespace Kigo
