@@ -1,21 +1,7 @@
 /*
-    Copyright 2008 Sascha Peilicke <sasch.pe@gmx.de>
+    SPDX-FileCopyrightText: 2008 Sascha Peilicke <sasch.pe@gmx.de>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy
-    defined in Section 14 of version 3 of the license.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "mainwindow.h"
@@ -272,9 +258,9 @@ void MainWindow::finishGame()
     Score score = m_game->estimatedScore();
     QString name;
     if (score.color() == QLatin1Char('W')) {
-        name = m_game->whitePlayer().name() + " (White)";
+        name = i18n("%1 (White)", m_game->whitePlayer().name());
     } else {
-        name = m_game->blackPlayer().name() + " (Black)";
+        name = i18n("%1 (Black)", m_game->blackPlayer().name());
     }
     // Show a score message that stays visible until the next
     // popup message arrives
@@ -402,15 +388,15 @@ void MainWindow::passMovePlayed(const Player &player)
 void MainWindow::setupActions()
 {
     // Game menu
-    m_newGameAction = KStandardGameAction::gameNew(this, SLOT(newGame()), actionCollection());
-    m_loadGameAction = KStandardGameAction::load(this, SLOT(loadGame()), actionCollection());
+    m_newGameAction = KStandardGameAction::gameNew(this, &MainWindow::newGame, actionCollection());
+    m_loadGameAction = KStandardGameAction::load(this, QOverload<>::of(&MainWindow::loadGame), actionCollection());
     m_getMoreGamesAction = new QAction(QIcon::fromTheme( QStringLiteral( "get-hot-new-stuff") ), i18nc("@action", "Get More Games..." ), this);
-    actionCollection()->setDefaultShortcut(m_getMoreGamesAction, Qt::CTRL + Qt::Key_G);
+    actionCollection()->setDefaultShortcut(m_getMoreGamesAction, Qt::CTRL | Qt::Key_G);
     m_getMoreGamesAction->setToolTip(i18nc("@action", "Get More Games..."));
     connect(m_getMoreGamesAction, &QAction::triggered, this, &MainWindow::getMoreGames);
     actionCollection()->addAction( QStringLiteral( "get_more_games" ), m_getMoreGamesAction);
-    m_saveAction = KStandardGameAction::save(this, SLOT(saveGame()), actionCollection());
-    KStandardGameAction::quit(this, SLOT(close()), actionCollection());
+    m_saveAction = KStandardGameAction::save(this, &MainWindow::saveGame, actionCollection());
+    KStandardGameAction::quit(this, &QWidget::close, actionCollection());
 
     m_startGameAction = new QAction(QIcon::fromTheme( QStringLiteral( "media-playback-start") ), i18nc("@action", "Start Game" ), this);
     actionCollection()->setDefaultShortcut(m_startGameAction, Qt::Key_S);
@@ -425,12 +411,12 @@ void MainWindow::setupActions()
     actionCollection()->addAction( QStringLiteral( "game_finish" ), m_finishGameAction);
 
     // Move menu
-    m_undoMoveAction = KStandardGameAction::undo(this, SLOT(undo()), actionCollection());
-    m_redoMoveAction = KStandardGameAction::redo(this, SLOT(redo()), actionCollection());
-    m_passMoveAction = KStandardGameAction::endTurn(this, SLOT(pass()), actionCollection());
+    m_undoMoveAction = KStandardGameAction::undo(this, &MainWindow::undo, actionCollection());
+    m_redoMoveAction = KStandardGameAction::redo(this, &MainWindow::redo, actionCollection());
+    m_passMoveAction = KStandardGameAction::endTurn(this, &MainWindow::pass, actionCollection());
     m_passMoveAction->setText(i18nc("@action:inmenu Move", "Pass Move"));
     actionCollection()->setDefaultShortcut(m_passMoveAction,Qt::Key_P);
-    m_hintAction = KStandardGameAction::hint(this, SLOT(hint()), actionCollection());
+    m_hintAction = KStandardGameAction::hint(this, &MainWindow::hint, actionCollection());
 
     // View menu
     m_moveNumbersAction = new KToggleAction(QIcon::fromTheme( QStringLiteral( "lastmoves") ), i18nc("@action:inmenu View", "Show Move &Numbers" ), this);
@@ -440,7 +426,7 @@ void MainWindow::setupActions()
     actionCollection()->addAction( QStringLiteral( "move_numbers" ), m_moveNumbersAction);
 
     // Settings menu
-    KStandardAction::preferences(this, SLOT(showPreferences()), actionCollection());
+    KStandardAction::preferences(this, &MainWindow::showPreferences, actionCollection());
 }
 
 void MainWindow::setupDockWindows()
